@@ -57,10 +57,10 @@ public:
      */
     ChatTab* getTab(const Tp::TextChannelPtr &incomingTextChannel);
 
-    void focusChat(ChatTab* tab);
+    void focusChat(ChatTab *tab);
 
-    void addTab(ChatTab* tab);
-    void removeTab(ChatTab* tab);
+    void addTab(ChatTab *tab);
+    void removeTab(ChatTab *tab);
 
 Q_SIGNALS:
     /** to emit before closing a window. This signal tells telepathyChatUi to remove the closed
@@ -100,6 +100,7 @@ private Q_SLOTS:
     void onOpenLogTriggered();                                  /** Starts ktp-log-viewer accountId contactId */
     void setTabSpellDictionary(const QString &dict);            /** set the spelling language for the current chat tab*/
     void toggleBlockButton(bool contactIsBlocked);              /** Toggle block/unblock action according to the flag */
+    void updateAccountIcon();                                   /** Update account icon fake action */
 
 protected Q_SLOTS:
     void showSettingsDialog();
@@ -134,9 +135,6 @@ private:
     void setShareDesktopEnabled(bool enable);
     void setPreviousConversationsEnabled(bool enable);
 
-    /** setter for account icon fake action */
-    void setAccountIcon(const QIcon &protocolIcon);
-
     /** starts audio call with given contact
      * @param account account sending the audio call request
      * @param contact contact with whom to start audio call
